@@ -130,7 +130,7 @@ Set/Get the values for this series.
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 LICENSE
 
